@@ -280,11 +280,6 @@ class VariableUrUserNewPw(Variable):
     def check(self, value):
         if not value:
             raise VariableError(_("Empty password"))
-        if not all([len(value) > 7,
-                    any([x.isupper() for x in value]),
-                    any([x.islower() for x in value]),
-                    any([x.isdigit() for x in value])]):
-            raise VariableError(_("Password should contain at least 8 symbols, 1 uppercase letter, 1 lowercase letter, 1 digit"))
 
 
 class VariableClClientLogin(user.VariableUrLogin):
